=========
wikiquote
=========

The ``wikiquote`` Python 3 module allows you to search and retrieve quotes from any Wikiquote article, and also retrieve the quote of the day. Please keep in mind that due to Wikiquote's varying article layouts, some quotes may not be retrieved correctly.

For more information, please visit the project's `GitHub repo <https://github.com/federicotdn/wikiquote>`_.
